package com.ruoyi.web.controller.student;

import java.util.List;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuRoom;
import com.ruoyi.system.service.IStuRoomService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 寝室Controller
 * 
 * @author liql
 * @date 2021-06-17
 */
@RestController
@RequestMapping("/dorm/room")
@Api(value = "寝室管理",tags={"寝室管理"})
public class StuRoomController extends BaseController
{
    @Autowired
    private IStuRoomService stuRoomService;

    /**
     * 查询寝室列表
     */
    //@PreAuthorize("@ss.hasPermi('dorm:room:list')")
    @GetMapping("/list")
    public TableDataInfo list(StuRoom stuRoom)
    {
        startPage();
        List<StuRoom> list = stuRoomService.selectStuRoomList(stuRoom);
        return getDataTable(list);
    }

    /**
     * 导出寝室列表
     */
    @PreAuthorize("@ss.hasPermi('dorm:room:export')")
    @Log(title = "寝室", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(StuRoom stuRoom)
    {
        List<StuRoom> list = stuRoomService.selectStuRoomList(stuRoom);
        ExcelUtil<StuRoom> util = new ExcelUtil<StuRoom>(StuRoom.class);
        return util.exportExcel(list, "room");
    }

    /**
     * 获取寝室详细信息
     */
    @PreAuthorize("@ss.hasPermi('dorm:room:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuRoomService.selectStuRoomById(id));
    }

    /**
     * 新增寝室
     */
    @PreAuthorize("@ss.hasPermi('dorm:room:add')")
    @Log(title = "寝室", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StuRoom stuRoom)
    {
        return toAjax(stuRoomService.insertStuRoom(stuRoom));
    }

    /**
     * 修改寝室
     */
    @PreAuthorize("@ss.hasPermi('dorm:room:edit')")
    @Log(title = "寝室", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuRoom stuRoom)
    {
        return toAjax(stuRoomService.updateStuRoom(stuRoom));
    }

    /**
     * 删除寝室
     */
    @PreAuthorize("@ss.hasPermi('dorm:room:remove')")
    @Log(title = "寝室", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuRoomService.deleteStuRoomByIds(ids));
    }

    /**
     * 获取专业列表
     */
    @GetMapping(value = "/query-list/{buildingId}/{roomType}")
    @ApiOperation("根据楼宇id获取寝室列表")
    public TableDataInfo getList(@PathVariable("buildingId") Long buildingId,@PathVariable("roomType") Integer roomType)
    {
        return getDataTable(stuRoomService.queryRoomByBuildingId(buildingId,roomType));
    }
}
