package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuRoomMapper;
import com.ruoyi.system.domain.StuRoom;
import com.ruoyi.system.service.IStuRoomService;

/**
 * 寝室Service业务层处理
 * 
 * @author liql
 * @date 2021-06-17
 */
@Service
public class StuRoomServiceImpl implements IStuRoomService 
{
    @Autowired
    private StuRoomMapper stuRoomMapper;

    /**
     * 查询寝室
     * 
     * @param id 寝室ID
     * @return 寝室
     */
    @Override
    public StuRoom selectStuRoomById(Long id)
    {
        return stuRoomMapper.selectStuRoomById(id);
    }

    /**
     * 查询寝室列表
     * 
     * @param stuRoom 寝室
     * @return 寝室
     */
    @Override
    public List<StuRoom> selectStuRoomList(StuRoom stuRoom)
    {
        return stuRoomMapper.selectStuRoomList(stuRoom);
    }

    /**
     * 新增寝室
     * 
     * @param stuRoom 寝室
     * @return 结果
     */
    @Override
    public int insertStuRoom(StuRoom stuRoom)
    {
        stuRoom.setCreateTime(DateUtils.getNowDate());
        return stuRoomMapper.insertStuRoom(stuRoom);
    }

    /**
     * 修改寝室
     * 
     * @param stuRoom 寝室
     * @return 结果
     */
    @Override
    public int updateStuRoom(StuRoom stuRoom)
    {
        stuRoom.setUpdateTime(DateUtils.getNowDate());
        return stuRoomMapper.updateStuRoom(stuRoom);
    }

    /**
     * 批量删除寝室
     * 
     * @param ids 需要删除的寝室ID
     * @return 结果
     */
    @Override
    public int deleteStuRoomByIds(Long[] ids)
    {
        return stuRoomMapper.deleteStuRoomByIds(ids);
    }

    /**
     * 删除寝室信息
     * 
     * @param id 寝室ID
     * @return 结果
     */
    @Override
    public int deleteStuRoomById(Long id)
    {
        return stuRoomMapper.deleteStuRoomById(id);
    }

    /**
     * @param roomName
     * @return int
     * @Description 根据寝室名查询寝室
     */
    @Override
    public StuRoom queryRoomByName(String roomName) {
        return stuRoomMapper.queryRoomByName(roomName);
    }

    /**
     * @param buildingId
     * @return java.util.List<com.ruoyi.system.domain.StuRoom>
     * @Description 根据楼宇id查询寝室列表
     */
    @Override
    public List<StuRoom> queryRoomByBuildingId(Long buildingId,Integer roomType) {
        return stuRoomMapper.queryRoomByBuildingId(buildingId,roomType);
    }
}
